EnPT documentation
==================


**This documentation is structured as follows:**

.. toctree::
   :maxdepth: 2

   about
   Source code repository <https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT>
   installation
   usage
   algorithm_descriptions.rst
   tutorial
   modules
   contributing
   development
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
